@@ -6,7 +6,7 @@ use warnings FATAL => 'all';
 use MRO::Compat;
 use Devel::InnerPackage qw/list_packages/;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 our $this_package = __PACKAGE__; # so it can be used in hash keys
 
@@ -130,7 +130,7 @@ Catalyst::Plugin::AutoCRUD - Instant AJAX web front-end for DBIx::Class
 
 =head1 VERSION
 
-This document refers to version 0.54 of Catalyst::Plugin::AutoCRUD
+This document refers to version 0.55 of Catalyst::Plugin::AutoCRUD
 
 =head1 PURPOSE
 
@@ -183,22 +183,19 @@ interface after a page refresh.
 
 =head2 Read Me First
 
-If you're upgrading from L<CatalystX::ListFramework::Builder>, please note the
-following important changes:
+If you created your C<DBIx::Class> Schema some time ago, perhaps using an
+older version of C<DBIx::Class::Schema::Loader>, then it might well be lacking
+some configuration which is required to get the best results from this plugin.
 
-=over 4
+Common omissions in column configurations include C<is_foreign_key>,
+C<join_type>, C<is_nullable>, and C<is_auto_increment>. Of course it's also
+good practice to have your C<DBIx::Class> Schema closely reflect the database
+schema anyway.
 
-=item *
-
-The base URL path now defaults to C</autocrud> if you don't set it.  Override
-this with the C<basepath> option.
-
-=item * 
-
-You probably want to delete the C<extjs2> option from your config, as this
-plugin can now pull the files from CacheFly.
-
-=back
+To automatically bring things up to date, download the latest version of
+L<DBIx::Class::Schema::Loader> from CPAN (which may be 0.05 or a pre-release),
+and use the output from that. If you don't yet have a Schema, continue reading
+and Scenario 2, below, will cover the steps required.
 
 =head2 Scenario 1: Plugin to an existing Catalyst App
 
@@ -319,8 +316,7 @@ of the foreign table, the names of the primary keys, and associated values
 
 If you created your C<DBIx::Class> Schema some time ago, perhaps using an
 older version of C<DBIx::Class::Schema::Loader>, then it might well be lacking
-some configuration which is important to get the best results from this
-plugin.
+some configuration which is required to get the best results from this plugin.
 
 Common omissions in column configurations include C<is_foreign_key>,
 C<join_type>, C<is_nullable>, and C<is_auto_increment>. Of course it's also
@@ -695,31 +691,36 @@ server (e.g. Apache) which is different from the default site itself.
 
 =head2 Foreign keys should be configured with C<is_foreign_key>
 
-Any column in your Result Classes that contains the primary key of another
+Any column in your result classes which contains the primary key of another
 table should have the C<< is_foreign_key => 1 >> option added to its
 configuration.
 
 Not doing this will cause the affected column to appear twice in your table,
-with a C<(REF)> suffix on the heading, rather than once with a C<(FK)> suffix.
-The technical reason for this, if you are interested, is that
-C<is_foreign_key> is used by C<DBIx::Class> to differentiate between
-C<has_one> and C<belongs_to> type relations. The plugin will emit an error
-level log message if it detects this problem.
+with a C<(REF)> suffix on the heading, rather than once with an C<(FK)>
+suffix.  The technical reason for this, if you are interested, is that
+C<is_foreign_key> is used by this plugin to differentiate between C<has_one>
+and C<belongs_to> type relations. The plugin will emit an error level log
+message if it detects this problem.
 
 If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
 version 0.05 or the most recent development release from CPAN to have this
-configured for you.
+automatically configured for you.
 
 =head2 Make sure C<belongs_to> follows C<add_columns>
 
-Again, because C<DBIx::Class> looks for the C<is_foreign_key> option on
-the column when setting up the relation accessor, make sure you issue the
-C<belongs_to> call B<after> you have issued C<add_columns>. The plugin will
-emit an error level log message if it detects this problem.
+Whenver you use C<belongs_to()> in a result class, it B<must> come after any
+calls to C<add_column()> which affect the foreign key. A situation where this
+may not be the case is if you add additional column options in a second call
+to C<add_column()>, after the C<DO NOT MODIFY THIS OR ANYTHING ABOVE> line.
 
-If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
-version 0.05 or the most recent development release from CPAN to have this
-configured for you.
+If you do not follow this guideline, then you won't see any related data in 
+the views generated by this plugin. Furthermore, you'll be losing much of
+the advantage of C<DBIx::Class>, so this plugin will emit an error log
+level message if it detects this problem.
+
+A better solution is to re-generate your result class using a recent version
+of C<DBIx::Class::Schema::Loader> from the CPAN (which may be 0.05 or a
+pre-release).
 
 =head2 Optional C<belongs_to> relations must have a C<join_type>
 
@@ -739,24 +740,24 @@ like so:
 If you don't do this, some database records will be missing! The plugin will
 emit an error level log message if it detects this problem. The technical
 reason for this, if you are interested, is that C<DBIx::Class> defaults to an
-INNER join for the C<belongs_to> relation, but if the column can be null (that
-is, C<is_nullable>) then you instead want a LEFT OUTER join.
+INNER join for the C<belongs_to()> relation, but if the column can be null (that
+is, C<is_nullable>) then you most likely want a LEFT OUTER join.
 
 If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
 version 0.05 or the most recent development release from CPAN to have this
-configured for you.
+automatically configured for you.
 
 =head2 Columns with auto-increment data types
 
 For those columns where your database uses an auto-incremented value, add the
-C<< is_auto_increment => 1, >> parameter to the options list in
+C<< is_auto_increment => 1 >> parameter to the options list in
 C<add_columns()>.  This will let the plugin know you don't need to supply a
 value for new or updated records. The interface will look much better as a
 result.
 
 If using C<DBIx::Class::Schema::Loader> to generate your Schema, use at least
 version 0.05 or the most recent development release from CPAN to have this
-configured for you.
+automatically configured for you.
 
 =head1 EXAMPLES
 
